<?php

namespace Rock_Convert\Inc\Admin;

use Rock_Convert\Inc\Admin\Custom_Post as Custom_Post;

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @link       https://rockcontent.com
 * @since      1.0.0
 *
 * @author    Rock Content
 */
class Admin {

  /**
   * The ID of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $plugin_name    The ID of this plugin.
   */
  private $plugin_name;

  /**
   * The version of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $version    The current version of this plugin.
   */
  private $version;

  /**
   * The text domain of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $plugin_text_domain    The text domain of this plugin.
   */
  private $plugin_text_domain;

  /**
   * WP_List_Table object
   *
   * @since    1.0.0
   * @access   private
   * @var      user_list_table    $user_list_table
   */
  private $user_list_table;

  /**
   * Initialize the class and set its properties.
   *
   * @since    1.0.0
   * @param    string $plugin_name	The name of this plugin.
   * @param    string $version	The version of this plugin.
   * @param	 string $plugin_text_domain	The text domain of this plugin
   */
  public function __construct( $plugin_name, $version, $plugin_text_domain ) {

    $this->plugin_name = $plugin_name;
    $this->version = $version;
    $this->plugin_text_domain = $plugin_text_domain;

  }

  /**
   * Register the stylesheets for the admin area.
   *
   * @since    1.0.0
   */
  public function enqueue_styles() {

    wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rock-convert-admin.css', array(), $this->version, 'all' );

  }

  /**
   * Register the JavaScript for the admin area.
   *
   * @since    1.0.0
   */
  public function enqueue_scripts() {

    $params = array ( 'ajaxurl' => admin_url( 'admin-ajax.php' ) );
    wp_enqueue_script( 'rock_convert_ajax_handle', plugin_dir_url( __FILE__ ) . 'js/rock-convert-admin.js', array( 'jquery' ), $this->version, false );
    wp_localize_script( 'rock_convert_ajax_handle', 'params', $params );

  }

  public function register_cta_post_type() {
    new Custom_Post();
  }

}
